Module type_graph

Module type_graph 

Type graph analysis — extracts pubkey field references from IDL type definitions.

Structs

PubkeyFieldRef
A reference to a pubkey field within a type definition.
TypeNode
A node in the type graph representing a type that contains pubkey fields.

Functions

extract_type_graph
Extract a type graph from an IDL spec.