Type graph analysis — extracts pubkey field references from IDL type definitions.
Structs
- Pubkey
Field Ref - A reference to a pubkey field within a type definition.
- Type
Node - A node in the type graph representing a type that contains pubkey fields.
Functions
- extract_
type_ graph - Extract a type graph from an IDL spec.